/*
        Copyright (c) 1998, Apple Computer, Inc.
        All rights reserved.

        You may freely copy, distribute and reuse the code in this example.
        Apple disclaims any warranty of any kind, expressed or implied,
        as to its fitness for any particular use.
*/

#import "FlatFileAdaptor.h"
#import "FlatFileChannel.h"

@class EOAttribute;

typedef enum {
    EOIntegerType,
    EODoubleType,
    EODecimalNumberType
} EONumberColumnValueType;

@interface FlatFileColumn:NSObject
{
    EOAttribute *attribute;
    int bindingIndex;
}

+ (Class)columnClassForAttribute:(EOAttribute *)attr;
+ columnForAttribute:(EOAttribute *)attr channel:(FlatFileChannel *)channel;

- initWithAttribute:(EOAttribute*)attr channel:(FlatFileChannel *)channel;
- (EOAttribute *)attribute;

- (void)bindAtIndex:(int)index;
- (int)bindingIndex;
- (id)newValueForBytes:(void *)bytes length:(int)length;

@end

@interface FlatFileNumberColumn:FlatFileColumn
{
    EONumberColumnValueType valueType;
}

- (id)newValueForBytes:(void *)bytes length:(int)length;

@end

@interface FlatFileStringColumn:FlatFileColumn
{
    NSStringEncoding encoding;
}

- initWithAttribute:(EOAttribute *)attr channel:(FlatFileChannel *)channel;
- initWithAttribute:(EOAttribute *)attr channel:(FlatFileChannel *)channel encoding:(NSStringEncoding)anEncoding;
- (NSStringEncoding)encoding;
- (void)setEncoding:(NSStringEncoding)anEncoding;
- (id)newValueForBytes:(void *)bytes length:(int)length;

@end

@interface FlatFileDataColumn:FlatFileColumn

- (id)newValueForBytes:(void *)bytes length:(int)length;

@end

@interface FlatFileDateColumn:FlatFileColumn
{
}

- (id)newValueForBytes:(void *)bytes length:(int)length;

@end
